import re

from odoo import models
from odoo.tools.translate import _
from odoo.exceptions import UserError


class ResUsers(models.Model):
    _inherit = 'res.users'

    def _can_import_remote_urls(self):
        """:func:`_parse_import_data` is used to limit number of remote imports.
        For databases that don't have `base_import` installed see
        :func:`saas_trial.models.res_users._can_import_remote_urls`.
        """
        return True


class Import(models.TransientModel):
    _inherit = 'base_import.import'

    def _parse_import_data(self, data, import_fields, options):
        default_image_regex = r"(?:http|https)://.*(?:png|jpe?g|tiff?|gif|bmp)"
        image_fields = ["icon", "image", "image_1920", "image_1024", "image_512", "image_256", "image_128", "logo", "picture"]
        count = 0
        limit = 100
        # see https://github.com/odoo/odoo/commit/db403e6dd70e14e7275a955a84e8aab607c4711d#diff-433eb965d529965f1fde28bf20ad504eR721
        # and comments on https://github.com/odoo/odoo/pull/17375 for details about the original heuristic.
        for name, field in self.env[self.res_model].fields_get(allfields=image_fields, attributes=['type', 'attachment']).items():
            if field['type'] == 'binary' and field.get('attachment') and name in import_fields:
                index = import_fields.index(name)
                for num, line in enumerate(data):
                    if re.match(default_image_regex, line[index]):
                        count += 1
                        if count > limit:
                            raise UserError(_('Cannot import more than %d images via URL, please consider splitting up the file.') % limit)
        return super(Import, self)._parse_import_data(data, import_fields, options)
